# AnimalAI
![steampunkFOURcrop](https://github.com/Kinds-of-Intelligence-CFI/animal-ai/assets/65875290/df798f4a-cb2c-416f-a150-093b9382a621)
Animal-AI (3) Python Project

This repository is responsible for managing and updating primarily the PyPI package (https://pypi.org/project/animalai/) for Animal-AI project package dependencies. 

The main project is located here: https://github.com/Kinds-of-Intelligence-CFI/animal-ai.

The Animal-AI (3) Unity project repository is here: https://github.com/Kinds-of-Intelligence-CFI/animal-ai-unity-project.

## Version History

- v3.0.3
  - Asserted python version to be 3.6.1 or higher, but less than 3.10.0 (exclusive).
  - Added package description to setup.py and package metadata.
- v3.0.2
  - Fixed major pacakge dependency issues, related to mlagents 0.30.0, protopuf, and shimy.
  - Updated project setup.py to accomodate the latest version of Animal-AI package dependencies.
    - Users can now use # pip install animalai # to install from PyPI directly (previously had to be done via locally). 
